==> FHLBBS-4.2.tgz: wbbs/ua_read.c <==
#include "cgic.h"
#include "wbbs.c"

FILE *fptr1,*fptr2;
char buf1[200];




int cgiMain() {
   char *foo, path1[100], path2[100], oneline[301],buf2[100],genbuf[128];
   char *ptr,backup[100];
   char article[IDLEN+1];
   time_t t1;
   char *pt1,*pt2;
   int len1, fd, numposts, i,j;
   signed int numarticle, filecount, fd1;
   int ptmode;
   int readmode; //readmode=0 Qװ readmode=1 mail
   struct fileheader readfile;
   struct stat st;
   boardheader *bp;
   boardheader *getbcache();
   char *bdname;
   int querymode=0;//=0 use number to query, =1 prev =2 next 
   strncpy(currboard, getenv("QUERY_STRING"),IDLEN+IDLEN);
   currboard[IDLEN+IDLEN]=0;
   
   foo = rindex(currboard, '_');
   if (foo)
   {
   	*(foo++) = '\0';
   	numarticle = atoi(foo);
    if (numarticle) article[0]=0;
    else strcpy(article,foo); 
   }
   else //J~
   {
        querymode=0;
        numarticle=0;
        article[0]=0;
   }
   

   if (strrchr(currboard,'/')) //ȬOhacker
   {
      cgiHeaderContentType("text/html");
      fprintf(cgiOut,"<h1>AOhackerܡH</h1><p>\n");
      return(0);
   }   
   bdname=currboard;
 
   /*** ˬdQװv  **/
   bp = getbcache(bdname);
   strcpy(cuser.userid,"guest");
   cuser.userlevel=0;
   if ((!bp)||(!Ben_Perm(bp))){
      cgiHeaderContentType("text/html");
      fprintf(cgiOut,"S %s oӰQװϡI<p>\n", bdname);
      return(0);
   }
   
   sprintf(path1,BBSHOME "/boards/%s/.DIR", currboard);
   if( stat(path1, &st ) >= 0 )
      numposts = st.st_size / (sizeof( struct fileheader ));
   else
      numposts = 0;

   /**** Ū̫@gN^峹C **/
   if (article[0]==0)
   {
     if (numarticle<=0) numarticle=numposts+numarticle; /* pGJt */
     if (numarticle<=0) numarticle=1;
     if(numarticle > numposts)
     {
	  numarticle = numposts;
	  sprintf(oneline, "boards.cgi?%s", bdname);
       cgiHeaderLocation(oneline);
     }
   }
   cgiHeaderContentType("text/html");
 
  /* o٭n@UA]nҼ{O_vAHΨCӪDiHק  */
   sprintf(buf2, "%s%s", DEFDIR, READPRE);
   if( (fptr2 = fopen(buf2,"r")) == NULL )
   {
     fprintf(cgiOut,"%sɮ׶}ҿ~<br>",buf2);
     return 0;
   }
   else
   {
    while(fgets(oneline, 300, fptr2) != NULL)  
    {
      pt1=oneline;
      while (pt2=strstr(pt1,"<!--$"))
      {
         *pt2=0;
         pt2=pt2+5;
         fprintf(cgiOut,"%s", pt1);/* LXtokener */
         pt1=strstr(pt2,"-->");
         if (pt1==NULL) 
         {
            fprintf(cgiOut,"榡ɿ~IP@椺䤣 -->");
            return 0;
         }
         *pt1=0;
         pt1=pt1+3;
         ptmode=atoi(pt2);
         if (ptmode==0) //Dn\
         {
                
	   strncpy(exchange,article,64);
           sprintf(path2,BBSHOME "/boards/%s/%s", currboard, 
           article);
         if((fptr1 = fopen(path2, "r")) == NULL){
            fprintf(cgiOut, "%s }ɥ\n", path1);
         return -1;
         }
	     strcpy(backup,currboard);//W䧮currboard|ñ
         pfile(fptr1);
         fclose(fptr1);

         if (readmode==0)
         {
	       strcpy(currboard,backup);//ҥHunbackupӳƥF
            setbfile(genbuf,currboard,"wreadnum");
            logcnt(genbuf);/*p\Ū*/
         }
        }
        else // other mode
            SSI(ptmode);
      }
      fprintf(cgiOut,"%s", pt1);
    }
      fclose(fptr2);
   }

   return 0;
}

==> FHLBBS-5.3.tgz: wbbs/ua_read.c <==
#include "cgic.h"
#include "wbbs.c"

FILE *fptr1,*fptr2;
char buf1[200];




int cgiMain() {
   char *foo, path1[100], path2[100], oneline[301],buf2[100],genbuf[128];
   char *ptr,backup[100];
   char article[IDLEN+1];
   time_t t1;
   char *pt1,*pt2;
   int len1, fd, numposts, i,j;
   signed int numarticle, filecount, fd1;
   int ptmode;
   int readmode; //readmode=0 Qװ readmode=1 mail
   struct fileheader readfile;
   struct stat st;
   boardheader *bp;
   boardheader *getbcache();
   char *bdname;
   int querymode=0;//=0 use number to query, =1 prev =2 next 
   strncpy(currboard, getenv("QUERY_STRING"),IDLEN+IDLEN);
   currboard[IDLEN+IDLEN]=0;
   
   foo = rindex(currboard, '/');
   if (foo)
   {
   	*(foo++) = '\0';
   	numarticle = atoi(foo);
    if (numarticle) article[0]=0;
    else strcpy(article,foo); 
   }
   else //J~
   {
        querymode=0;
        numarticle=0;
        article[0]=0;
   }
   

   if (strrchr(currboard,'.')) //ȬOhacker
   {
      cgiHeaderContentType("text/html");
      fprintf(cgiOut,"<h1>AOhackerܡH</h1><p>\n");
      return(0);
   }   
   bdname=currboard;
 
   /*** ˬdQװv  **/
   bp = getbcache(bdname);
   strcpy(cuser.userid,"guest");
   cuser.userlevel=0;
   if ((!bp)||(!Ben_Perm(bp))){
      cgiHeaderContentType("text/html");
      fprintf(cgiOut,"S %s oӰQװϡI<p>\n", bdname);
      return(0);
   }
   
   sprintf(path1,BBSHOME "/boards/%s/.DIR", currboard);
   if( stat(path1, &st ) >= 0 )
      numposts = st.st_size / (sizeof( struct fileheader ));
   else
      numposts = 0;

   /**** Ū̫@gN^峹C **/
   if (article[0]==0)
   {
     if (numarticle<=0) numarticle=numposts+numarticle; /* pGJt */
     if (numarticle<=0) numarticle=1;
     if(numarticle > numposts)
     {
	  numarticle = numposts;
	  sprintf(oneline, "boards.cgi?%s", bdname);
       cgiHeaderLocation(oneline);
     }
   }
   cgiHeaderContentType("text/html");
 
  /* o٭n@UA]nҼ{O_vAHΨCӪDiHק  */
   sprintf(buf2, "%s%s", DEFDIR[doorid], READPRE);
   if( (fptr2 = fopen(buf2,"r")) == NULL )
   {
     fprintf(cgiOut,"%sɮ׶}ҿ~<br>",buf2);
     return 0;
   }
   else
   {
    while(fgets(oneline, 300, fptr2) != NULL)  
    {
      pt1=oneline;
      while (pt2=strstr(pt1,"<!--$"))
      {
         *pt2=0;
         pt2=pt2+5;
         fprintf(cgiOut,"%s", pt1);/* LXtokener */
         pt1=strstr(pt2,"-->");
         if (pt1==NULL) 
         {
            fprintf(cgiOut,"榡ɿ~IP@椺䤣 -->");
            return 0;
         }
         *pt1=0;
         pt1=pt1+3;
         ptmode=atoi(pt2);
         if (ptmode==0) //Dn\
         {
                
	   strncpy(exchange,article,64);
           sprintf(path2,BBSHOME "/boards/%s/%s", currboard, 
           article);
         if((fptr1 = fopen(path2, "r")) == NULL){
            fprintf(cgiOut, "%s }ɥ\n", path1);
         return -1;
         }
	     strcpy(backup,currboard);//W䧮currboard|ñ
         pfile(fptr1);
         fclose(fptr1);

         if (readmode==0)
         {
	       strcpy(currboard,backup);//ҥHunbackupӳƥF
            setbfile(genbuf,currboard,"wreadnum");
            logcnt(genbuf);/*p\Ū*/
         }
        }
        else // other mode
            SSI(ptmode);
      }
      fprintf(cgiOut,"%s", pt1);
    }
      fclose(fptr2);
   }

   return 0;
}
